@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -940,14 +940,16 @@ anjuta_launcher_execution_done_cleanup (AnjutaLauncher *launcher,
 	{	
 		g_io_channel_shutdown (launcher->priv->stdout_channel, emit_signal, NULL);
 		g_io_channel_unref (launcher->priv->stdout_channel);
-		g_source_remove (launcher->priv->stdout_watch);
+		if (!launcher->priv->stdout_is_done)
+			g_source_remove (launcher->priv->stdout_watch);
 	}
 
 	if (launcher->priv->stderr_channel)
 	{
 		g_io_channel_shutdown (launcher->priv->stderr_channel, emit_signal, NULL);
 		g_io_channel_unref (launcher->priv->stderr_channel);
-		g_source_remove (launcher->priv->stderr_watch);
+		if (!launcher->priv->stderr_is_done)
+			g_source_remove (launcher->priv->stderr_watch);
 	}
 
 	if (launcher->priv->pty_channel)
