@@ -634,10 +634,7 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	g_object_set (G_OBJECT (git_plugin->remote_branch_list_command),
 	              "working-directory", git_plugin->project_root_directory, 
 	              NULL);
-	g_object_set (G_OBJECT (git_plugin->commit_status_command),
-	              "working-directory", git_plugin->project_root_directory,
-	              NULL);
-	g_object_set (G_OBJECT (git_plugin->not_updated_status_command),
+	g_object_set (G_OBJECT (git_plugin->status_command),
 	              "working-directory", git_plugin->project_root_directory,
 	              NULL);
 	g_object_set (G_OBJECT (git_plugin->remote_list_command),
@@ -654,13 +651,13 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	              NULL);
 
 	anjuta_command_start_automatic_monitor (ANJUTA_COMMAND (git_plugin->local_branch_list_command));
-	anjuta_command_start_automatic_monitor (ANJUTA_COMMAND (git_plugin->commit_status_command));
+	anjuta_command_start_automatic_monitor (ANJUTA_COMMAND (git_plugin->status_command));
 	anjuta_command_start_automatic_monitor (ANJUTA_COMMAND (git_plugin->remote_list_command));
 	anjuta_command_start_automatic_monitor (ANJUTA_COMMAND (git_plugin->tag_list_command));
 	anjuta_command_start_automatic_monitor (ANJUTA_COMMAND (git_plugin->stash_list_command));
 	anjuta_command_start_automatic_monitor (ANJUTA_COMMAND (git_plugin->ref_command));
 	anjuta_command_start (ANJUTA_COMMAND (git_plugin->local_branch_list_command));
-	anjuta_command_start (ANJUTA_COMMAND (git_plugin->commit_status_command));
+	anjuta_command_start (ANJUTA_COMMAND (git_plugin->status_command));
 	anjuta_command_start (ANJUTA_COMMAND (git_plugin->remote_list_command));
 	anjuta_command_start (ANJUTA_COMMAND (git_plugin->tag_list_command));
 	anjuta_command_start (ANJUTA_COMMAND (git_plugin->stash_list_command));
@@ -681,7 +678,7 @@ on_project_root_removed (AnjutaPlugin *plugin, const gchar *name,
 	status = anjuta_shell_get_status (plugin->shell, NULL);
 	
 	anjuta_command_stop_automatic_monitor (ANJUTA_COMMAND (git_plugin->local_branch_list_command));
-	anjuta_command_stop_automatic_monitor (ANJUTA_COMMAND (git_plugin->commit_status_command));
+	anjuta_command_stop_automatic_monitor (ANJUTA_COMMAND (git_plugin->status_command));
 	anjuta_command_stop_automatic_monitor (ANJUTA_COMMAND (git_plugin->remote_list_command));
 	anjuta_command_stop_automatic_monitor (ANJUTA_COMMAND (git_plugin->tag_list_command));
 	anjuta_command_stop_automatic_monitor (ANJUTA_COMMAND (git_plugin->stash_list_command));
@@ -910,13 +907,8 @@ git_activate_plugin (AnjutaPlugin *plugin)
 	                  G_CALLBACK (on_branch_list_command_data_arrived),
 	                  plugin);
 
-	/* Create the status list commands. The different commands correspond to 
-	 * the two different sections in status output: Changes to be committed 
-	 * (staged) and Changed but not updated (unstaged.) */
-	git_plugin->commit_status_command = git_status_command_new (NULL,
-	                                                            GIT_STATUS_SECTION_COMMIT);
-	git_plugin->not_updated_status_command = git_status_command_new (NULL,
-	                                                                 GIT_STATUS_SECTION_NOT_UPDATED);
+	/* Status list commands */
+	git_plugin->status_command = git_status_command_new (NULL);
 
 	/* Remote list command */
 	git_plugin->remote_list_command = git_remote_list_command_new (NULL);
@@ -924,12 +916,6 @@ git_activate_plugin (AnjutaPlugin *plugin)
 	/* Ref list command. used to keep the log up to date */
 	git_plugin->ref_command = git_ref_command_new (NULL);
 
-	/* Always run the not updated commmand after the commmit command. */
-	g_signal_connect (G_OBJECT (git_plugin->commit_status_command), 
-	                  "command-finished",
-	                  G_CALLBACK (run_next_command),
-	                  git_plugin->not_updated_status_command);
-
 	/* Tag list command */
 	git_plugin->tag_list_command = git_tag_list_command_new (NULL);
 
@@ -1029,8 +1015,7 @@ git_deactivate_plugin (AnjutaPlugin *plugin)
 
 	g_object_unref (git_plugin->local_branch_list_command);
 	g_object_unref (git_plugin->remote_branch_list_command);
-	g_object_unref (git_plugin->commit_status_command);
-	g_object_unref (git_plugin->not_updated_status_command);
+	g_object_unref (git_plugin->status_command);
 	g_object_unref (git_plugin->remote_list_command);
 	g_object_unref (git_plugin->tag_list_command);
 	g_object_unref (git_plugin->stash_list_command);
