@@ -2,6 +2,7 @@
 /*
     plugin.c
     Copyright (C) 2000 Naba Kumar
+    Copyright (C) 2014 Tristian Celestin
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,35 +37,31 @@
 #define PREFS_BUILDER PACKAGE_DATA_DIR"/glade/anjuta-terminal-plugin.ui"
 #define ICON_FILE "anjuta-terminal-plugin-48.png"
 
-/* Some desktop/gnome-terminal gconf keys. */
-#define GCONF_MONOSPACE_FONT      "/desktop/gnome/interface/monospace_font_name"
-#define GCONF_DEFAULT_PROFILE     "/apps/gnome-terminal/global/default_profile"
-#define GCONF_PROFILE_LIST        "/apps/gnome-terminal/global/profile_list"
+/* Gnome-Terminal GSettings Schemas and Keys */
+#define TERM_PROFILE_LIST_SCHEMA		"org.gnome.Terminal.ProfilesList"
+#define TERM_LEGACY_SCHEMA				"org.gnome.Terminal.Legacy.Settings"
+#define TERM_PROFILE_DEFAULT			"default"
 
-#define GCONF_PROFILE_PREFIX      "/apps/gnome-terminal/profiles"
-#define GCONF_BACKGROUND_COLOR    "background_color"
-#define GCONF_BACKSPACE_BINDING   "backspace_binding"
-#define GCONF_CURSOR_BLINK        "cursor_blink"
-#define GCONF_DELETE_BINDING      "delete_binding"
-#define GCONF_EXIT_ACTION         "exit_action"
-#define GCONF_VTE_TERMINAL_FONT   "font"
-#define GCONF_FOREGROUND_COLOR    "foreground_color"
-#define GCONF_SCROLLBACK_LINES    "scrollback_lines"
-#define GCONF_SCROLL_ON_KEYSTROKE "scroll_on_keystroke"
-#define GCONF_SCROLL_ON_OUTPUT    "scroll_on_output"
-#define GCONF_SILENT_BELL         "silent_bell"
-#define GCONF_USE_SYSTEM_FONT     "use_system_font"
-#define GCONF_WORD_CHARS          "word_chars"
-#define GCONF_PTY_FLAGS           "pty_flags"
+/* Gnome Desktop GSettings Schemas and Keys */
+#define GNOME_DESKTOP_INTERFACE_SCHEMA			"org.gnome.desktop.interface"
+#define GNOME_MONOSPACE_FONT					"monospace-font-name"
 
+/* Anjuta Terminal Plugin Schema and Keys */
 #define PREF_SCHEMA                           "org.gnome.anjuta.terminal"
-#define PREFS_TERMINAL_PROFILE_USE_DEFAULT    "terminal-default-profile"
+#define PREFS_TERMINAL_PROFILE_USE_DEFAULT    "use-default-profile"
 #define PREFS_TERMINAL_PROFILE                "terminal-profile"
 
+/* Columns in model for combo box */
+enum {
+	TERM_STORE_UUID_COLUMN,
+	TERM_STORE_NAME_COLUMN
+};
+
 #include <vte/vte.h>
 #include <pwd.h>
 #include <gtk/gtk.h>
 #include <libanjuta/anjuta-plugin.h>
+#include "terminal-schemas.h"
 
 extern GType terminal_plugin_get_type (GTypeModule *module);
 #define ANJUTA_PLUGIN_TERMINAL_TYPE         (terminal_plugin_get_type (NULL))
@@ -108,7 +105,7 @@ static gpointer parent_class;
 static const gchar*
 get_profile_key (const gchar *profile, const gchar *key)
 {
-	/* A resonably safe buffer */
+	/* A reasonably safe buffer */
 	static gchar buffer[1024];
 
 	g_return_val_if_fail (profile != NULL && key != NULL, NULL);
@@ -118,130 +115,168 @@ get_profile_key (const gchar *profile, const gchar *key)
 }
 #endif
 
+static gboolean
+strv_to_rgbav (const gchar **specs, gsize *size, GdkRGBA **colors)
+{
+	GVariant *var;
+	gint i;
+	GVariantIter iter;
+	const char *str;
+
+	var = g_variant_new_strv (specs, -1);
+	g_variant_iter_init (&iter, var);
+	*size = g_variant_iter_n_children (&iter);
+	*colors = g_new (GdkRGBA, *size);
+	i = 0;
+	while (g_variant_iter_next (&iter, "&s", &str)) {
+		if (!gdk_rgba_parse (&(*colors)[i++], str)) {
+			g_free (*colors);
+			g_variant_unref (var);
+			return FALSE;
+		}
+	}
+	g_variant_unref (var);
+	return TRUE;
+}
+
 static void
 terminal_set_preferences (VteTerminal *term, GSettings* settings, TerminalPlugin *term_plugin)
 {
-#if 0
-	char *text;
-	int value;
-	gboolean setting;
-	GdkColor color[2];
-	GdkColor* foreground;
-	GdkColor* background;
-	gchar *profile;
+	gchar *uuid;
+	gchar *path;
+	GSettings *profiles_list;
+	GSettings *profile_settings;
+	GSettings *interface_settings;
+	gboolean bool_val;
+	gchar *str_val;
+	gchar **str_vals;
+	gint int_val;
+	gsize size;
+	GdkRGBA color[2];
+	GdkRGBA *foreground;
+	GdkRGBA *background;
+	GdkRGBA *palette;
 
 	g_return_if_fail (settings != NULL);
 
-	/* Update the currently available list of terminal profiles */
-	setting = g_settings_get_boolean (settings,
-	                                  PREFS_TERMINAL_PROFILE_USE_DEFAULT);
-	if (setting)
-	{
-		// TODO: Get from GSettings instead of GConf
-		/* Use the currently selected profile in gnome-terminal */
-		text = gconf_client_get_string (client, GCONF_DEFAULT_PROFILE, NULL);
-	}
-	else
-	{
-		/* Otherwise use the user selected profile */
-		text = g_settings_get_string (settings, PREFS_TERMINAL_PROFILE);
-	}
-	if (!text || (*text == '\0'))
-			text = g_strdup ("Default");
-	profile = text;
+	profiles_list = g_settings_new (TERMINAL_PROFILES_LIST_SCHEMA);
 
+	/* Get selected profile */
+	bool_val = g_settings_get_boolean (settings, PREFS_TERMINAL_PROFILE_USE_DEFAULT);
+	if (bool_val)
+		uuid = g_settings_get_string (profiles_list, TERMINAL_SETTINGS_LIST_DEFAULT_KEY);
+	else
+		uuid = g_settings_get_string (settings, PREFS_TERMINAL_PROFILE);
+	path = g_strdup_printf ("%s:%s/", TERMINAL_PROFILES_PATH_PREFIX, uuid);
+	profile_settings = g_settings_new_with_path (TERMINAL_PROFILE_SCHEMA, path);
+	g_free (uuid);
+	g_free (path);
+
+	/* Always autohide mouse */
 	vte_terminal_set_mouse_autohide (term, TRUE);
 
-	/* Set terminal font either using the desktop wide font or g-t one. */
-	setting = g_settings_get_boolean (GCONF_USE_SYSTEM_FONT);
-	if (setting) {
-		text = gconf_client_get_string (client, GCONF_MONOSPACE_FONT, NULL);
-		if (!text)
-			text = GET_PROFILE_STRING (GCONF_VTE_TERMINAL_FONT);
-	} else {
-		text = GET_PROFILE_STRING (GCONF_VTE_TERMINAL_FONT);
-	}
-	if (text)
-		vte_terminal_set_font_from_string (term, text);
-	g_free (text);
-
-	setting = GET_PROFILE_BOOL (GCONF_CURSOR_BLINK);
-	vte_terminal_set_cursor_blink_mode ((term),
-	                                    setting ? VTE_CURSOR_BLINK_ON : VTE_CURSOR_BLINK_OFF);
-	setting = GET_PROFILE_BOOL (GCONF_SILENT_BELL);
-	vte_terminal_set_audible_bell (term, !setting);
-	value = GET_PROFILE_INT (GCONF_SCROLLBACK_LINES);
-	vte_terminal_set_scrollback_lines (term, (value == 0) ? 500 : value);
-	setting = GET_PROFILE_BOOL (GCONF_SCROLL_ON_KEYSTROKE);
-	vte_terminal_set_scroll_on_keystroke (term, setting);
-	setting = GET_PROFILE_BOOL (GCONF_SCROLL_ON_OUTPUT);
-	vte_terminal_set_scroll_on_output (term, TRUE);
-	text = GET_PROFILE_STRING (GCONF_WORD_CHARS);
-	if (text)
-		vte_terminal_set_word_chars (term, text);
-	g_free (text);
-
-	text = GET_PROFILE_STRING (GCONF_BACKSPACE_BINDING);
-	if (text)
+	/* Set terminal font */
+	bool_val = g_settings_get_boolean (profile_settings, TERMINAL_PROFILE_USE_SYSTEM_FONT_KEY);
+	if (bool_val)
 	{
-		if (!strcmp (text, "ascii-del"))
-			vte_terminal_set_backspace_binding (term,
-								VTE_ERASE_ASCII_DELETE);
-		else if (!strcmp (text, "escape-sequence"))
-			vte_terminal_set_backspace_binding (term,
-								VTE_ERASE_DELETE_SEQUENCE);
-		else if (!strcmp (text, "control-h"))
-			vte_terminal_set_backspace_binding (term,
-								VTE_ERASE_ASCII_BACKSPACE);
+		interface_settings = g_settings_new (GNOME_DESKTOP_INTERFACE_SCHEMA);
+		str_val = g_settings_get_string (interface_settings, GNOME_MONOSPACE_FONT);
+		g_object_unref (interface_settings);
+	} else
+	{
+		str_val = g_settings_get_string (profile_settings, TERMINAL_PROFILE_FONT_KEY);
+	}
+	if (str_val != NULL)
+		vte_terminal_set_font_from_string (term, str_val);
+
+	/* Set cursor blink */
+	str_val = g_settings_get_string (profile_settings, TERMINAL_PROFILE_CURSOR_BLINK_MODE_KEY);
+	if (g_strcmp0 (str_val, "system") == 0)
+		vte_terminal_set_cursor_blink_mode (term, VTE_CURSOR_BLINK_SYSTEM);
+	else if (g_strcmp0 (str_val, "on") == 0)
+		vte_terminal_set_cursor_blink_mode (term, VTE_CURSOR_BLINK_ON);
+	else if (g_strcmp0 (str_val, "off") == 0)
+		vte_terminal_set_cursor_blink_mode (term, VTE_CURSOR_BLINK_OFF);
+	g_free (str_val);
+
+	/* Set audible bell */
+	bool_val = g_settings_get_boolean (profile_settings, TERMINAL_PROFILE_AUDIBLE_BELL_KEY);
+	vte_terminal_set_audible_bell (term, bool_val);
+
+	/* Set scrollback */
+	int_val = g_settings_get_int (profile_settings, TERMINAL_PROFILE_SCROLLBACK_LINES_KEY);
+	vte_terminal_set_scrollback_lines (term, (int_val == 0) ? 500 : int_val);
+
+	/* Set scroll on keystroke */
+	bool_val = g_settings_get_boolean (profile_settings, TERMINAL_PROFILE_SCROLL_ON_KEYSTROKE_KEY);
+	vte_terminal_set_scroll_on_keystroke (term, bool_val);
+
+	/* Scroll on output */
+	bool_val = g_settings_get_boolean (profile_settings, TERMINAL_PROFILE_SCROLL_ON_OUTPUT_KEY);
+	vte_terminal_set_scroll_on_output (term, bool_val);
+
+	/* Set word characters */
+	str_val = g_settings_get_string (profile_settings, TERMINAL_PROFILE_WORD_CHARS_KEY);
+	if (str_val != NULL)
+		vte_terminal_set_word_chars (term, str_val);
+	g_free (str_val);
+
+	/* Set backspace key */
+	str_val = g_settings_get_string (profile_settings, TERMINAL_PROFILE_BACKSPACE_BINDING_KEY);
+	if (str_val != NULL)
+	{
+		if (g_strcmp0 (str_val, "ascii-del") == 0)
+			vte_terminal_set_backspace_binding (term, VTE_ERASE_ASCII_DELETE);
+		else if (g_strcmp0 (str_val, "escape-sequence") == 0)
+			vte_terminal_set_backspace_binding (term, VTE_ERASE_DELETE_SEQUENCE);
+		else if (g_strcmp0 (str_val, "control-h") == 0)
+			vte_terminal_set_backspace_binding (term, VTE_ERASE_ASCII_BACKSPACE);
 		else
-			vte_terminal_set_backspace_binding (term,
-								VTE_ERASE_AUTO);
-		g_free (text);
+			vte_terminal_set_backspace_binding (term, VTE_ERASE_AUTO);
 	}
-	text = GET_PROFILE_STRING (GCONF_DELETE_BINDING);
-	if (text)
+	g_free (str_val);
+
+	/* Set delete key */
+	str_val = g_settings_get_string (profile_settings, TERMINAL_PROFILE_DELETE_BINDING_KEY);
+	if (str_val != NULL)
 	{
-		if (!strcmp (text, "ascii-del"))
-			vte_terminal_set_delete_binding (term,
-							 VTE_ERASE_ASCII_DELETE);
-		else if (!strcmp (text, "escape-sequence"))
-			vte_terminal_set_delete_binding (term,
-							 VTE_ERASE_DELETE_SEQUENCE);
-		else if (!strcmp (text, "control-h"))
-			vte_terminal_set_delete_binding (term,
-							 VTE_ERASE_ASCII_BACKSPACE);
+		if (g_strcmp0 (str_val, "ascii-del") == 0)
+			vte_terminal_set_delete_binding (term, VTE_ERASE_ASCII_DELETE);
+		else if (g_strcmp0 (str_val, "escape-sequence") == 0)
+			vte_terminal_set_delete_binding (term, VTE_ERASE_DELETE_SEQUENCE);
+		else if (g_strcmp0 (str_val, "control-h") == 0)
+			vte_terminal_set_delete_binding (term, VTE_ERASE_ASCII_BACKSPACE);
 		else
-			vte_terminal_set_delete_binding (term,
-							 VTE_ERASE_AUTO);
-		g_free (text);
+			vte_terminal_set_delete_binding (term, VTE_ERASE_AUTO);
 	}
-	/* Set fore- and background colors. */
-	text = GET_PROFILE_STRING (GCONF_BACKGROUND_COLOR);
-	if (text)
-	{
-		gdk_color_parse (text, &color[0]);
-		g_free (text);
-	}
-	background = text ? &color[0] : NULL;
-	text = GET_PROFILE_STRING (GCONF_FOREGROUND_COLOR);
-	if (text)
-	{
-		gdk_color_parse (text, &color[1]);
-		g_free (text);
-	}
-	foreground = text ? &color[1] : NULL;
-	/* vte_terminal_set_colors works even if the terminal widget is not realized
-	 * which is not the case with vte_terminal_set_color_foreground and
-	 * vte_terminal_set_color_background */
-	vte_terminal_set_colors (term, foreground, background, NULL, 0);
+	g_free (str_val);
 
-	/* vte_terminal is not working depending on update_records setting at least
-	 * on FreeBSD */
-	term_plugin->pty_flags = GET_PROFILE_INT_DEFAULT (GCONF_PTY_FLAGS,VTE_PTY_DEFAULT);
+	/* Set colors (foreground, background, and palette) */
+	str_val = g_settings_get_string (profile_settings, TERMINAL_PROFILE_BACKGROUND_COLOR_KEY);
+	if (str_val != NULL)
+		bool_val = gdk_rgba_parse (&color[0], str_val);
+	background = bool_val ? &color[0] : NULL;
+	g_free (str_val);
 
-	g_free (profile);
-	g_object_unref (client);
-#endif
+	str_val = g_settings_get_string (profile_settings, TERMINAL_PROFILE_FOREGROUND_COLOR_KEY);
+	if (str_val != NULL)
+		bool_val = gdk_rgba_parse (&color[1], str_val);
+	foreground = bool_val ? &color[1] : NULL;
+	g_free (str_val);
+
+	str_vals = g_settings_get_strv(profile_settings, TERMINAL_PROFILE_PALETTE_KEY);
+	strv_to_rgbav (str_vals, &size, &palette);
+	g_free (str_vals);
+
+	/* vte_terminal_set_colors() works even if the terminal widget is not realized,
+	 * which is not the case with vte_terminal_set_color_foreground() and
+	 * vte_terminal_set_color_background()
+	 */
+	vte_terminal_set_colors_rgba (term, foreground, background, palette, size);
+
+	g_free (palette);
+	g_object_unref (profiles_list);
+	g_object_unref (profile_settings);
 }
 
 static void
@@ -863,51 +898,64 @@ iterminal_iface_init(IAnjutaTerminalIface *iface)
 	iface->execute_command = iterminal_execute_command;
 }
 
-#if 0
 static void
-on_add_string_in_store (gpointer data, gpointer user_data)
+add_data_to_store (gchar *uuid, gchar *name, GtkListStore *model)
 {
-	GtkListStore* model = (GtkListStore *)user_data;
 	GtkTreeIter iter;
 
 	gtk_list_store_append (model, &iter);
-	gtk_list_store_set (model, &iter, 0, (const gchar *)data, -1);
+	gtk_list_store_set (model, &iter, TERM_STORE_UUID_COLUMN, uuid, TERM_STORE_NAME_COLUMN, name, -1);
 }
 
 static void
-on_concat_string (gpointer data, gpointer user_data)
+profile_renderer (GtkTreeViewColumn *column, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 {
-	GString* str = (GString *)user_data;
+	gchar *uuid;
+	gchar *name;
+	gchar *label;
 
-	if (str->len != 0)
-		g_string_append_c (str, ',');
-	g_string_append (str, data);
+	gtk_tree_model_get (model, iter, TERM_STORE_UUID_COLUMN, &uuid, TERM_STORE_NAME_COLUMN, &name, -1);
+	label = g_strdup_printf ("%s (%s)", name, uuid);
+	g_object_set (renderer, "text", label, NULL);
+	g_free (uuid);
+	g_free (name);
+	g_free (label);
 }
 
 static void
 on_pref_profile_changed (GtkComboBox* combo, TerminalPlugin* term_plugin)
 {
-	GtkTreeModel* model = gtk_combo_box_get_model (combo);
+	GtkTreeModel *model = gtk_combo_box_get_model (combo);
 	GtkTreeIter iter;
-	gchar* text;
+	gchar *uuid;
 
-	gtk_combo_box_get_active_iter (combo,
-	                               &iter);
-	gtk_tree_model_get (model, &iter, 0, &text, -1);
-	g_settings_set_string (term_plugin->settings,
-	                       PREFS_TERMINAL_PROFILE,
-	                       text);
-	g_free (text);
+	gtk_combo_box_get_active_iter (combo, &iter);
+	gtk_tree_model_get (model, &iter, TERM_STORE_UUID_COLUMN, &uuid, -1);
+	g_settings_set_string (term_plugin->settings, PREFS_TERMINAL_PROFILE, uuid);
+	g_free (uuid);
 }
-#endif
 
 static void
 ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError** e)
 {
-	GError* error = NULL;
+	GSettings *terminal_settings;
+	GSettings *profile_settings;
+	GtkListStore *store;
+	GtkTreeIter iter;
+	gchar *default_uuid;
+	gchar *saved_uuid;
+	gchar *temp;
+	gchar **profiles;
+	gchar *path;
+	gboolean iter_valid;
+	gboolean found;
+	int i;
+	GError *error = NULL;
+	GtkCellRenderer *name_renderer;
+	GtkCellRenderer *uuid_renderer;
 
 	/* Create the terminal preferences page */
-	TerminalPlugin* term_plugin = ANJUTA_PLUGIN_TERMINAL (ipref);
+	TerminalPlugin *term_plugin = ANJUTA_PLUGIN_TERMINAL (ipref);
 	GtkBuilder *bxml = gtk_builder_new ();
 
 	if (!gtk_builder_add_from_file (bxml, PREFS_BUILDER, &error))
@@ -922,40 +970,66 @@ ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError**
 	                                     "Terminal", _("Terminal"), ICON_FILE);
 
 	term_plugin->pref_profile_combo = GTK_WIDGET (gtk_builder_get_object (bxml, "profile_list_combo"));
-	term_plugin->pref_default_button = GTK_WIDGET (gtk_builder_get_object (bxml, "preferences_toggle:bool:1:0:terminal-default-profile"));
+	term_plugin->pref_default_button = GTK_WIDGET (gtk_builder_get_object (bxml, "preferences_toggle:bool:1:0:use-default-profile"));
 
-#if 0
-	GSList *profiles;
+	/* Add profile-name and profile-uuid renderers to combo box */
+	name_renderer = gtk_cell_renderer_text_new ();
+	uuid_renderer = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_clear (GTK_CELL_LAYOUT(term_plugin->pref_profile_combo));
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT(term_plugin->pref_profile_combo), name_renderer, TRUE);
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT(term_plugin->pref_profile_combo), uuid_renderer, FALSE);
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT(term_plugin->pref_profile_combo), name_renderer, "text", TERM_STORE_NAME_COLUMN);
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT(term_plugin->pref_profile_combo), uuid_renderer, "text", TERM_STORE_UUID_COLUMN);
+	g_object_set (uuid_renderer, "style", PANGO_STYLE_ITALIC, NULL);
 
-	/* FIXME: Update to GSettings */
-	/* Update the currently available list of terminal profiles */
-	client = gconf_client_get_default ();
-	profiles = gconf_client_get_list (client, GCONF_PROFILE_LIST,
-									  GCONF_VALUE_STRING, NULL);
-	if (profiles)
-	{
-		GtkListStore *store;
-		GString *default_value = g_string_new (NULL);
-
-		store = GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (term_plugin->pref_profile_combo)));
+	/* If at least a default profile exists ... */
+	terminal_settings = g_settings_new (TERMINAL_PROFILES_LIST_SCHEMA);
+	store = GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (term_plugin->pref_profile_combo)));
+	default_uuid = g_settings_get_string (terminal_settings, "default");
+	if (default_uuid != NULL) {
 
+		/* Populate profiles store */
+		profiles = g_settings_get_strv (terminal_settings, "list");
 		gtk_list_store_clear (store);
-		g_slist_foreach (profiles, on_add_string_in_store, store);
-		g_slist_foreach (profiles, on_concat_string, default_value);
-		g_slist_foreach (profiles, (GFunc)g_free, NULL);
-		g_slist_free (profiles);
+		for (i = 0; profiles[i] != NULL; i ++) {
+			path = g_strdup_printf ("%s:%s/", TERMINAL_PROFILES_PATH_PREFIX, profiles[i]);
+			profile_settings = g_settings_new_with_path (TERMINAL_PROFILE_SCHEMA, path);
+			temp = g_settings_get_string (profile_settings, TERMINAL_PROFILE_VISIBLE_NAME_KEY);
+			add_data_to_store (profiles[i], temp, store);
+		}
 
+		/* Display saved profile in combo box */
+		saved_uuid = g_settings_get_string (term_plugin->settings, PREFS_TERMINAL_PROFILE);
+		if (saved_uuid != NULL)
+		{
+			found = FALSE;
+			iter_valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter);
+			while (iter_valid && !found)
+			{
+				gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, TERM_STORE_UUID_COLUMN, &temp, -1);
+				if (g_strcmp0 (saved_uuid, temp) == 0)
+				{
+					gtk_combo_box_set_active_iter (GTK_COMBO_BOX (term_plugin->pref_profile_combo), &iter);
+					found = TRUE;
+				}
+				iter_valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (store), &iter);
+				g_free (temp);
+			}
+			g_free (saved_uuid);
+		}
+
+		/* Save profile selection if changed */
 		g_signal_connect (term_plugin->pref_profile_combo, "changed",
 		                  G_CALLBACK (on_pref_profile_changed), term_plugin);
 
+		/* Deactivate profile selection if not using default profile */
 		use_default_profile_cb (GTK_TOGGLE_BUTTON (term_plugin->pref_default_button), term_plugin);
 		g_signal_connect (G_OBJECT(term_plugin->pref_default_button), "toggled",
 						  G_CALLBACK (use_default_profile_cb), term_plugin);
 
-		g_string_free (default_value, TRUE);
+		g_object_unref(terminal_settings);
 	}
 	else
-#endif
 	{
 		/* No profile, perhaps GNOME Terminal is not installed,
 		 * Remove selection */
